/**
 * Fractal Binding Factory.
 * Copyright (C) 2007-2009 INRIA, SARDES

 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: Valerio.Schiavoni@gmail.com
 * 
 * Author: Valerio Schiavoni
 * 
 */
package org.objectweb.fractal.bf.connectors.ws;

import org.apache.cxf.frontend.ServerFactoryBean;
import org.objectweb.fractal.api.control.AttributeController;

/**
 * Attribute controller to configure the {@link WsSkeletonContent}.
 * 
 * @see WsSkeletonContent
 */
public interface WsSkeletonAttributes extends AttributeController {
	/**
	 * Set the uri of the web service.
	 * 
	 * @param uri
	 *            the uri to use
	 */
	public void setUri(String uri);

	/**
	 * Get the uri of the web service.
	 * 
	 * @return
	 */
	public String getUri();

	/**
	 * Set the class used by the {@link ServerFactoryBean} to generate the
	 * proxy.
	 * 
	 * @param serviceClass
	 *            the class used by the {@link ServerFactoryBean} to generate
	 *            the proxy.
	 */
	public void setServiceClass(Class<?> serviceClass);

	/**
	 * Get the class used by the {@link ServerFactoryBean} to generate the
	 * proxy.
	 * 
	 * @return the class used by the {@link ServerFactoryBean} to generate the
	 *         proxy.
	 */
	public Class<?> getServiceClass();

	/**
	 * Set the name of the fractal interface on used to locate the business
	 * interface on the component owning the interface.
	 * 
	 * @param itfName
	 */
	public void setInterfaceName(String itfName);

	/**
	 * Get the name of the fractal interface on used to locate the business
	 * interface on the component owning the interface.
	 */
	public String getInterfaceName();

}
