/**
 * Fractal Binding Factory.
 * Copyright (C) 2007-2009 INRIA, SARDES

 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: Valerio.Schiavoni@gmail.com
 * 
 * Author: Valerio Schiavoni
 * 
 */
package org.objectweb.fractal.bf.connectors.ws;

import org.objectweb.fractal.api.control.AttributeController;
import org.objectweb.fractal.bf.BindingFactoryClassLoader;

/**
 * Attribute controller for web service stubs.
 */
public interface WsStubAttributes extends AttributeController {
	/**
	 * Set the wsdlLocation.
	 * 
	 * @param uri
	 *            the uri of the wsdl to use
	 */
	public void setWsdlLocation(String uri);

	/**
	 * Get the uri of the wsdl to use.
	 * 
	 * @return
	 */
	public String getWsdlLocation();

	/**
	 * Set the uri of the web service the stub is bound to.
	 * 
	 * @param uri
	 *            the uri to use
	 */
	public void setUri(String uri);

	/**
	 * Get the uri of the web service the stub is bound to.
	 * 
	 * @return
	 */
	public String getUri();

	/**
	 * Set the wsdlElement used to configure the stub.
	 * 
	 * @param wsdlElement
	 */
	public void setWsdlElement(String wsdlElement);

	/**
	 * Get the wsdlElement used to configure the stub.
	 * 
	 * @return the wsdlElement used to configure the stub.
	 */
	public String getWsdlElement();

	public void setServiceClass(Class<?> clazz);

	public Class<?> getServiceClass();

	public void setClassLoader(BindingFactoryClassLoader cl);

	public BindingFactoryClassLoader getClassLoader();
}
